Lightweight SQLx wrapper that emits OpenTelemetry-native spans and metrics following the database client semantic conventions.
Lightweight SQLx wrapper that emits OpenTelemetry-native spans and metrics following the database client semantic conventions.